@@ -813,10 +813,6 @@ def from_json(manifest_data: Dict, manifest_database_file: str) -> Manifest:
             "file_hash": manifest_file["hash"],
         })
 
-    with open("D:/work/bugs/IC-7317/debug.json", "w") as f:
-        import json
-        json.dump(file_data, f, indent=2)
-
     manifest.database.bulk_load_files(file_data=file_data)
     ht_to_db_id = {
         item["hyperthought_id"]: item["id"]
