@@ -1247,6 +1247,60 @@ class Database:
         result = cursor.fetchone()
         return result["file_count"]
 
+    def update_folder_hyperthought_id(self,
+        old_id: str,
+        new_id: str,
+        commit: bool = True,
+    ) -> None:
+        """
+        Update database when an existing folder is found in HyperThought.
+
+        Change the id of the folder record, as well as id paths for all
+        progeny.
+
+        Parameters
+        ----------
+        old_id : str
+            The id of the folder according to the database.
+        new_id : str
+            The id of the folder in HyperThought.
+        commit : bool
+            Determines whether changes will be committed to the database.
+            This may be false if the changes are part of a transaction.
+        """
+        cursor = self.connection.cursor()
+
+        # Get the folder record.
+        sql = "SELECT * FROM File WHERE hyperthought_id = :old_id"
+        cursor.execute(sql, {"old_id": old_id})
+        folder = cursor.fetchone()
+
+        if not folder:
+            return
+
+        # Reset id for folder record.
+        updates = {"hyperthought_id": new_id}
+        self.update_file(id_=folder["id"], updates=updates, commit=commit)
+
+        # Reset id paths for progeny.
+        parent_path = folder["hyperthought_id_path"]
+        old_id_path = f"{parent_path}{old_id},"
+        new_id_path = f"{parent_path}{new_id},"
+        sql = """
+        UPDATE File
+        SET hyperthought_id_path = REPLACE(
+            hyperthought_id_path, :old_id_path, :new_id_path)
+        WHERE hyperthought_id_path LIKE :pattern
+        """
+        cursor.execute(sql, {
+            "old_id_path": old_id_path,
+            "new_id_path": new_id_path,
+            "pattern": f"{old_id_path}%"
+        })
+
+        if commit:
+            self.connection.commit()
+
     def has_connectivity_errors(self) -> bool:
         """Determine whether connectivity errors occurred."""
         sql = """
